@@ -10,7 +10,6 @@ import http.server
 import time
 from pathlib import Path
 import os
-import subprocess
 
 buffer_lock = threading.Lock()  # Optional, if you want thread safety
 
@@ -97,38 +96,9 @@ def show_static(plot_buffer):
     os.chdir(str(tmp_dir))
 
     # If running in Windows, open the file directly
-    file_path = f"file://{tmp_file.name}"
     if not is_termux():
         webbrowser.open(f"file://{tmp_file.name}")
         return
-    else:
-        try:
-            #subprocess.run(['termux-open', file_path], check=True)
-            # You can find these for other apps using various tools.
-            browser_package = 'com.android.chrome'
-            browser_activity = 'com.google.android.apps.chrome.Main'
-
-            # Construct the full command
-            # Note: The file path must be in a file URI format.
-            command = [
-                'am',
-                'start',
-                '-a', 'android.intent.action.VIEW',
-                '-d', f'{file_path}',
-                '-n', f'{browser_package}/{browser_activity}'
-            ]
-            # Use subprocess.run() to execute the command
-            try:
-                subprocess.run(command, check=True)
-                print(f"Successfully launched Chrome to view {file_path}")
-            except subprocess.CalledProcessError as e:
-                print(f"Error launching browser: {e}")
-            except FileNotFoundError:
-                print("Error: The 'am' command was not found. Are you in a Termux environment with root or special permissions?")
-            print(f"Successfully opened {file_path}")
-            return
-        except subprocess.CalledProcessError as e:
-            print(f"Error opening file: {e}")
         
 
     # Start a temporary local server in a separate, non-blocking thread
